#!/usr/bin/python3
# -*- encoding: utf-8 -*-

import os                                       # Knihovna pro spousteni systemovych prikazu
import RPi.GPIO as GPIO                         # Prace s GPIO vstupy/vystupy
import time                                     # Prace s casem
import urllib2                                  # Pro testovani, ze uz je k dispozici pripojeni k internetu


#---------------------------------------------------
# Test jestli uz je dostupne pripojeni na internet
# Opsano z: https://stackoverflow.com/questions/3764291/checking-network-connection
def internet_on():
    try:
        urllib2.urlopen('https://google.com', timeout=1)  # Misto adresy Google pouzivam adresu VPS serveru, ktery se stara o reverzni tunelovani na RPi
        return True
    except urllib2.URLError as err:
        return False

#---------------------------------------------------

shutdown_pin = 7                                # Pin. ktery se bude pouzivat pro vypinani dlouhym stavem "LOW"
boot_pin  = 25                                  # Pin, ktery bude pouzit pro signalizaci spousteni RPi

GPIO.setmode(GPIO.BCM)
GPIO.setwarnings(False)


GPIO.setup(shutdown_pin, GPIO.IN, pull_up_down=GPIO.PUD_UP)     # Nastaveni vypinaciho GPIO pinu jako vstup s Pull-Up odporem
GPIO.setup(boot_pin, GPIO.OUT)               # Doted byl boot_pin pin bez napeti (zvenku PULL-DOWNovany)
GPIO.output(boot_pin , GPIO.LOW)             # Ted se prepne na vystup a stahne do LOW (takze se vlastne na venek nic nedeje)

#---------------------------------------------------
# Pri spusteni skriptu se az 20 sekund provadi test dostupnosti internetu
#---------------------------------------------------
for i in range (20):                            # 20 smycek se snazi RPi najit tunelovaci server na internetu
  time.sleep(1)                                 # V kazde smycce je mezi pokusy sekundova pauza
  if (internet_on() == True):                   # Kdyz je dostupny internet
    for blik in range (10):                     # ... provede se 10x rychle prepnuti stavu na boot_pinu
      GPIO.output(boot_pin , GPIO.LOW)          # (LOW impulz trva 0.1 sek.)
      time.sleep(0.1)                           
      GPIO.output(boot_pin , GPIO.HIGH)         # (LOW impulz trva 0.2 sek.)
      time.sleep(0.2)                           

    break                                       # Dalsi testovani internetu uz neni treba


GPIO.output(boot_pin , GPIO.HIGH)               # I kdyby se za 20 sekund nepodarilo pripojit k internetu, se bootovaci pin prepne do HIGH


#---------------------------------------------------
# Test vypinani pres shutdown_pin
#    Tuhle cast programu jsem predelal z puvodniho vypinani RPi pomoci dlouheho stisku tlacitka, ktere bylo primo pripojene na GPIO25.
#     Proto je tam to testovani delky trvani LOW stavu.
#     Pri pouziti ATtiny, ktere drzi tento stav trvale, by to testovani delky trvani LOW stavu mohlo byt vynechane.
#     Takto napsany kod ale zachovava moznost misto ATtiny pripojit pro vypnuti obycejne tlacitko
#---------------------------------------------------
while True:                                     # Nekonecna smycka.
  time.sleep(1)                                 # Kontrola vypinaciho pinu se provadi jen 1x za sekundu. (Kvuli odlehceni zateze procesoru)

  if (GPIO.input(shutdown_pin) == False):       # Kdyz je vypinaci pin ve stavu LOW, ...
    start_time = time.time()                    # ... zaznamena se aktualni cas.

    while (GPIO.input(shutdown_pin) == False):  # Dokud je vypinaci pin porad v LOW kontroluj delku trvani LOW stavu.
      time.sleep(0.5)                           # I pri tomto testovani se trochu odlehci zatez procesoru.
      if (time.time() - start_time > 2):        # Kdyz uz je cas trvani LOW delsi, nez 2 sekundy, ...
        prikaz="sudo shutdown -h now"           # ... vypni korektne RasPi.
        os.system (prikaz)                      # (prime spusteni prikazu pres BASH)


    # Kdyz byl cas trvani LOW stavu kratsi, nez 2 sekundy, pokracuj na zacatek nekonecne smycky a dal testuj stav vypinaciho pinu.

#---------------------------------------------------
